hwinfo

package
v1.1.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Copyright © 2023 Harry C <hoveychen@gmail.com>

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HWInfo

type HWInfo struct {
	CPUCores         int
	CPUThreads       int
	MemoryUsableGB   float32
	MemoryPhysicalGB float32
	GPUNames         []string
	MacAddresses     []string
	PlatformArch     string
	PlatformOS       string
}

func NewHWInfo

func NewHWInfo() *HWInfo

Jump to